# Get Started

:::{table}
:width: 90%
:align: left

| Steps | Links |
|--|--|
| 1. Check the requirements for the plugin before you start | [](1_prerequisites.md) |
| 2. Install the plugin & *napari* together | [](2_installation.md) |
| 3. Initial set up for the plugin in *napari* | [](3_setup.md)
:::

### You can also...

:::{table}
:width: 90%
:align: left

| Actions | Links |
|--|--|
| Learn about the features of the plugin | {ref}`Overview<Overview>` |
| View available pre-trained models | [Pre-trained models](4_pretrained-models.md) |
| Follow a step-by-step guide to get familiar with the plugin | {ref}`Step-by-step guide<Follow complete workflows>` |
| Jump straight to a process of interest | {ref}`How do I...<How do I...>` |
| Ask a question | {ref}`Resources` |
:::


:::{toctree}
:hidden:
1_prerequisites
2_installation
3_setup
4_pretrained-models
:::

